@@ -124,7 +124,7 @@ def getName(text: str):
     if alias == "":
         return name
     else:
-        return name + " / " + alias
+        return name + "\r" + alias
 
 def getCaseInfo(text: str):
     case_num = ""
@@ -433,7 +433,8 @@ def getCharges(text: str, cnum: str):
     return [convictions, dcharges, fcharges, cerv_convictions, pardon_convictions, perm_convictions, conviction_ct, charge_ct, cerv_ct, pardon_ct, perm_ct, conv_cerv_ct, conv_pardon_ct, conv_perm_ct, charge_codes, conv_codes, allcharge, charges]
 
 
-## CONFIGURATION METHODS - CALL ALAC.CONFIG() TO FEED CONF TO WRITE METHODS
+## CONFIGURATION METHODS 
+## CALL ALAC.CONFIG() TO FEED CONF TO WRITE METHODS
 def checkPath(path: str):
         head = os.path.split(path)[0]
         tail = os.path.split(path)[1]
@@ -513,14 +514,6 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
         except (AttributeError, KeyError, IndexError):
             raise Exception("Could not parse input object!")
 
-    ## TEXT INPUT
-    else:
-        if "ALABAMA SJIS CASE DETAIL" in input_path:
-            queue = [input_path]
-            pathMode = False
-        else:
-            raise Exception("Warning: Input not supported! Alacorder may fail.")
-
 
     content_length = queue.shape[0]
     if queue.shape[0] > max_cases and max_cases > 0: # cap input at max
@@ -592,7 +585,6 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
             print(f">>    ARCHIVE:  {'cases, charges, fees' if tables == '' else tables} to {'existing archive at: ' if appendArchive else ''}{archive_path}\n\n")
         print("\n")
 
-
 ## CONFIG OBJECT
     return pd.Series({
         'input_path': input_path,
@@ -669,20 +661,31 @@ def checkPath(path: str):
                 return PathType
     return PathType
 
-def write(conf, outputs):
+def write(conf, outputs, archive=False):
     max_cases = conf['count']
-    path_out = conf['table_out']
+    if path == '':
+        path_out = conf['table_out']
+    else:
+        path_out = conf['archive_out']
     print_log = conf['log']
     warn = conf['warn']
     try:
         out_ext = os.path.splitext(path_out)[1]
     except TypeError:
-        out_ext = ".xlsx"
-        print("Warning: default export to .xlsx. Investigate in debug!!") ### DEBUG MARKER
+        out_ext = ""
 
     if out_ext == ".xls":
-        with pd.ExcelWriter(path_out) as writer:
-            outputs.to_excel(writer, sheet_name="output-table")
+        try:
+            with pd.ExcelWriter(path_out) as writer:
+                outputs.to_excel(writer, sheet_name="output-table")
+        except ValueError:
+            try:
+                with pd.ExcelWriter(path_out,engine="xlwt") as writer:
+                    outputs.to_excel(writer, sheet_name="output-table")
+            except ValueError:
+                outputs.to_csv(path_out,escapechar='\\')
+                if warn or print_log:
+                    print("Exported to CSV due to XLSX engine failure")
     if out_ext == ".xlsx":
         try:
             with pd.ExcelWriter(path_out) as writer:
@@ -693,7 +696,8 @@ def write(conf, outputs):
                     outputs.to_excel(writer, sheet_name="output-table")
             except ValueError:
                 outputs.to_csv(path_out,escapechar='\\')
-                print("Exported to CSV due to XLSX engine failure")
+                if warn or print_log:
+                    print("Exported to CSV due to XLSX engine failure")
     elif out_ext == ".pkl":
         outputs.to_pickle(path_out+".xz",compression="xz")
     elif out_ext == ".xz":
@@ -711,21 +715,21 @@ def write(conf, outputs):
             print("Warning: Failed to export!")
     return outputs 
 
-
 def parseTables(config, tables=""): # aim to remove
-        if tables == "all" or tables == "all_cases" or tables == "":
-            a = alac.parseCases(config)
-        if tables == "cases":
-            a = alac.parseCaseInfo(config)
-        if tables == "fees":
-            a = alac.parseFees(config)
-        if tables == "charges":
-            a = alac.parseCharges(config)
-        if tables == "disposition":
-            a = alac.parseCharges(config)
-        if tables == "filing":
-            a = alac.parseCharges(config)
-        return a
+    a = []
+    if tables == "all" or tables == "all_cases" or tables == "":
+        a = parseCases(config)
+    if tables == "cases":
+        a = parseCaseInfo(config)
+    if tables == "fees":
+        a = parseFees(config)
+    if tables == "charges":
+        a = parseCharges(config)
+    if tables == "disposition":
+        a = parseCharges(config)
+    if tables == "filing":
+        a = parseCharges(config)
+    return a
 
 def writeArchive(conf): 
     path_in = conf['input_path']
@@ -754,7 +758,7 @@ def writeArchive(conf):
 
     outputs.fillna('',inplace=True)
 
-    write(conf, outputs)
+    write(conf, outputs, archive=True)
     log_complete(conf, start_time)
     return outputs
 
@@ -771,7 +775,9 @@ def parseFees(conf):
     if warn == False:
         warnings.filterwarnings("ignore")
     outputs = pd.DataFrame()
-    fees = pd.DataFrame({'CaseNumber': '', 'Code': '', 'Payor': '', 'AmtDue': '', 'AmtPaid': '', 'Balance': '', 'AmtHold': ''},index=[0])
+    fees = pd.DataFrame({'CaseNumber': '', 
+        'Code': '', 'Payor': '', 'AmtDue': '', 
+        'AmtPaid': '', 'Balance': '', 'AmtHold': ''},index=[0])
 
     if max_cases > 1000:
         batches = np.array_split(queue, math.ceil(max_cases / 1000))
@@ -1013,11 +1019,8 @@ def parseCases(conf):
         charges.fillna('',inplace=True)
         fees.fillna('',inplace=True)
         newcases = [cases, b]
-
         cases = cases.append(newcases, ignore_index=True)
-
         charges = charges[['CaseNumber', 'Num', 'Code', 'Description', 'Cite', 'CourtAction', 'CourtActionDate', 'Category', 'TypeDescription', 'Disposition', 'Permanent', 'Pardon', 'CERV','Conviction']]
-
         fees = fees[['CaseNumber', 'FeeStatus', 'AdminFee','Total', 'Code', 'Payor', 'AmtDue', 'AmtPaid', 'Balance', 'AmtHold']]
 
         # write 
